@@ -167,6 +167,12 @@ prep_rodent_output <- function(level_data, effort, na_drop,
     level_data <- dplyr::select(level_data, -"nplots")
   }
 
+  if (level == "treatment" && "newmoonnumber" %in% names(level_data)) {
+    level_data <- dplyr::filter(level_data,
+                                !(.data$treatment == 'spectabs' & .data$newmoonnumber > 340),
+                                !(.data$treatment == 'setup' & .data$newmoonnumber > 3))
+  }
+
   if (output == "rates") {
     grouping <- switch(level,
                        "plot" = c("species", "plot"),
